@@ -30,7 +30,6 @@ from PyQt4.QtGui import *
 from settingsUI2 import Ui_Form
 from todoy_conf import todoy_config
 import cPickle,os
-from PyQt4.QtMaemo5 import QMaemo5InformationBox
 
 
 class Settings(QWidget):
@@ -64,7 +63,8 @@ class Settings(QWidget):
  #page1 auto
 	 self.ui.checkBox.pressed.connect(self.setdefmode)# setdefault mode
 	 self.ui.checkBox_2.pressed.connect(self.setcalsyncmode)
-	 self.ui.comboBox.currentIndexChanged.connect(self.setdefevent)
+	 self.ui.comboBox_3.currentIndexChanged.connect(self.setpiecolor)#piecolor
+	 self.ui.comboBox.currentIndexChanged.connect(self.setdefevent)#defevent
 	 self.ui.fontComboBox.currentFontChanged.connect(self.setdeffont)
 	 #self.ui.lineEdit.textChanged.connect(self.setcalfile)
  #page2 gran
@@ -86,7 +86,7 @@ class Settings(QWidget):
  #page3 date
 
  #page4 sketch
-	 self.ui.backgroundTemplateLineEdit.textChanged.connect(self.setbkgrnd)
+	 #self.ui.backgroundTemplateLineEdit.textChanged.connect(self.setbkgrnd)
 	 self.ui.spinBox_14.setRange(1,20)
 	 self.ui.spinBox_14.setValue(self.tempconf.defaultpen_size)
 	 self.ui.spinBox_14.valueChanged.connect(self.setpensize)
@@ -94,6 +94,8 @@ class Settings(QWidget):
 	 self.ui.doubleSpinBox_15.setSingleStep(0.01)
 	 self.ui.doubleSpinBox_15.setValue(self.tempconf.ellipse_opacity)
 	 self.ui.doubleSpinBox_15.valueChanged.connect(self.setopacity)
+	 self.ui.comboBox_2.currentIndexChanged.connect(self.setpencolor)#piecolor
+	 self.ui.comboBox_4.currentIndexChanged.connect(self.setbkgrnd)#piecolor
 	 #self.show()
 
 
@@ -144,6 +146,27 @@ class Settings(QWidget):
 	elif index==1: self.tempconf.default_ev="TODO"
 	else: self.tempconf.default_ev="ALARM"
 	print "set default event as: " + self.tempconf.default_ev
+
+   def setpiecolor(self,index):
+	if index==0: 
+		self.tempconf.pie_color=Qt.green
+		self.tempconf.pie_randcolor=False
+	elif index==1: 
+		self.tempconf.pie_color=Qt.red
+		self.tempconf.pie_randcolor=False
+	elif index==2: 
+		self.tempconf.pie_color=Qt.blue
+		self.tempconf.pie_randcolor=False
+	elif index==3: 
+		self.tempconf.pie_color=Qt.yellow
+		self.tempconf.pie_randcolor=False
+	elif index==4: 
+		self.tempconf.pen_color=Qt.gray
+		self.tempconf.pie_randcolor=False
+	else: self.tempconf.pie_randcolor=True
+	#print "set default event as: " + self.tempconf.pie_color
+
+
    def setcalfile(self,text):
 	self.tempconf.cal_file=str(text)
 	print text
@@ -164,12 +187,36 @@ class Settings(QWidget):
 
 # page 3 ##############################################################
 # page 4 ##############################################################
-   def setbkgrnd(self, value):
-	self.tempconf.bkgrnd=value
+   def setbkgrnd(self, index):
+#	self.tempconf.bkgrnd="todoy_bkgrnd" + ".png"
+	if index==0: self.tempconf.bkgrnd="todoy_bkgrnd" +".png"
+	elif index==1: self.tempconf.bkgrnd="todoy_bkgrnd" +str(index)+ ".png"
+	elif index==2: self.tempconf.bkgrnd="todoy_bkgrnd" +str(index)+ ".png"
+	elif index==3: self.tempconf.bkgrnd="todoy_bkgrnd" +str(index)+ ".png"
+	elif index==4: self.tempconf.bkgrnd="todoy_bkgrnd" +str(index)+ ".png"
+#	elif index==5: self.tempconf.bkgrnd=value
+	else: self.tempconf.bkgrnd="todoy_bkgrnd" + ".png"
+
    def setpensize(self,value):
-	self.tempconf.default_pen_size=value
+	self.tempconf.defaultpen_size=value
    def setopacity(self,value):
 	self.tempconf.ellipse_opacity=value
+
+   def setpencolor(self,index):
+	if index==0: self.tempconf.pen_color=Qt.black
+	elif index==1: self.tempconf.pen_color=Qt.white
+	elif index==2: self.tempconf.pen_color=Qt.green
+	elif index==3: self.tempconf.pen_color=Qt.red
+	elif index==4: self.tempconf.pen_color=Qt.blue
+	elif index==5: self.tempconf.pen_color=Qt.yellow
+	else: self.tempconf.pen_color=Qt.gray
+
+
+
+
+
+
+
 def main():
      app = QApplication(sys.argv)
      window=Settings()
